@@ -1,3 +1,15 @@
+##----------------------------------------------------------------------------
+## Storable Improved with Bug Fixes - ~/lib/Storable/Improved.pm
+## Version v0.1.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Author: Jacques Deguest <jack@deguest.jp>
+## Created 2022/07/23
+## Modified 2022/07/24
+## All rights reserved
+## 
+## This program is free software; you can redistribute  it  and/or  modify  it
+## under the same terms as Perl itself.
+##----------------------------------------------------------------------------
 package Storable::Improved;
 BEGIN
 {
@@ -24,7 +36,7 @@ BEGIN
     *Deparse = \$Storable::Deparse;
     *Eval = \$Storable::Eval;
     *DEBUGME = \$Storable::DEBUGME;
-    $VERSION = 'v0.1.0';
+    $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -109,11 +121,11 @@ Storable::Improved - Storable improved with core flaws mitigated
 
 =head1 SYNOPSIS
 
-    use Storable;
+    use Storable::Improved;
     store \%table, 'file';
     $hashref = retrieve('file');
 
-    use Storable qw(nstore store_fd nstore_fd freeze thaw dclone);
+    use Storable::Improved qw(nstore store_fd nstore_fd freeze thaw dclone);
 
     # Network order
     nstore \%table, 'file';
@@ -140,11 +152,11 @@ Storable::Improved - Storable improved with core flaws mitigated
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
-L<Storable::Improved> is a thin module inheriting from L<Storable> and mitigating some of L<Storable> core flaws that have been pointed out to the development team (See L</"SEE ALSO">), but not addressed mostly due their unwillingness to do so. Hence, this module offers the implementation initially suggested.
+L<Storable::Improved> is a drop-in replacement for L<Storable>. It is a thin module inheriting from L<Storable> and mitigating some of L<Storable> core flaws that have been pointed out to the development team (See L</"SEE ALSO">), but not addressed mostly due their unwillingness to do so. Hence, this module offers the implementation initially suggested.
 
 As L<Storable> documentation states, "the L<Storable> package brings persistence to your Perl data structures containing C<SCALAR>, C<ARRAY>, C<HASH> or C<REF> objects, i.e. anything that can be conveniently stored to disk and retrieved at a later time."
 
@@ -163,7 +175,7 @@ L<Storable> would fail. For example:
     my $io = IO::File->new( __FILE__, 'r' );
     my $serialised = Storable::freeze( $io );
 
-would yield the fatar error:
+would yield the fatal error:
 
     Can't store GLOB items
 
@@ -184,7 +196,7 @@ would yield:
 
     Unexpected object type (8) in store_hook()
 
-Completely obscure and unhelpful and undocumented too. Whether C<STORABLE_freeze> returns anything makes no difference.
+Completely obscure and unhelpful error and undocumented too. Whether C<STORABLE_freeze> returns anything makes no difference.
 
 =item 2. Fail processing of XS module objects
 
@@ -206,9 +218,9 @@ For example:
     say "Is $h2 an object of HTTP::XSHeaders? ", ( $h2->isa( 'HTTP::XSHeaders' ) ? 'yes' : 'no' );
     say "Can $h2 do header? ", ( $h2->can( 'header' ) ? 'yes' : 'no' );
     say "Content-Type: ", $h2->header( 'Content-Type' );
-    # Exception occurs here: "hl is not an instance of HTTP::XSHeader"
+    # Exception occurs here: "hl is not an instance of HTTP::XSHeaders"
 
-would result in a fatal error C<hl is not an instance of HTTP::XSHeaders>
+would result in a fatal error C<hl is not an instance of HTTP::XSHeaders> even though C<< $h2->isa('HTTP::XSHeaders') >> returns true. This is because the object is created by L<Storable> and not by the XS module and is incompatible. Thus, you would think L<Storable> has successfully deserialised the data when it actually did not.
 
 =item 3. Output from C<STORABLE_thaw> is discarded
 
@@ -297,8 +309,6 @@ In most case, this is not needed and whatever your C<STORABLE_freeze> returns, L
 
 It returns the resulting serialised data created by C<Storable::freeze>
 
-Note that, by default C<$Storable::forgive_me> is set to true.
-
 =head2 thaw
 
 =head1 HOOKS
@@ -349,7 +359,7 @@ A word of caution here. What the original L<Storable> documentation does not tel
     say "Is $h2 an object of HTTP::XSHeaders? ", ( $h2->isa( 'HTTP::XSHeaders' ) ? 'yes' : 'no' );
     say "Can $h2 do header? ", ( $h2->can( 'header' ) ? 'yes' : 'no' );
     say "Content-Type: ", $h2->header( 'Content-Type' );
-    # Exception occurs here: "hl is not an instance of HTTP::XSHeader"
+    # Exception occurs here: "hl is not an instance of HTTP::XSHeaders"
 
 would produce:
 
